---
name: Feature request
about: Request a new sup3r feature
title: ''
labels: feature
assignees: ''

---

**Why this feature is necessary:**
Is your feature request related to a problem? Please describe. A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**A possible solution is:**
A clear and concise description of what you want to happen.

**I have considered the following alternatives:**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.

**Charge code**
If you are at NREL, please provide a task number for the developers to implement this feature.

**Urgency / Timeframe**
When do you need this feature by? How urgent is it related to other feature requests you've made?
